@@ -1,13 +1,14 @@
 import ctypes
 import pathlib
+import sys
 
-
+FILE_EXTENSION = {"darwin": "dylib", "linux": "so", "windows": "dll"}
 class _ChadwickLibrary:
     library_path = (
         pathlib.Path(__file__).absolute().parent.parent
         / "lib"
         / "cwevent"
-        / "libcwevent.so"
+        / f"libcwevent.{FILE_EXTENSION.get(sys.platform)}"
     )
 
     def __init__(self):
